/*********************************************************************************

Copyright(c) 2015 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/
/*
 *
 * File
 * Description	The two Sharcs come out of reset at approximately the same time.
 * 				This file conatins main() for Sharc 1. Sharc 1 manages the ADC.
 * 				Four channels of audio data are DMA'd into L1. The AdcCallback()
 * 				is executed for each frame of audio from the CODEC. The frame is
 * 				passed through a filter and the result is copied directly into
 * 				Sharc 2 L1 SRAM using MDMA.
 *
 */
#ifndef __MULTICORETALKTHRUSHARCSHARC_CORE1_H__
#define __MULTICORETALKTHRUSHARCSHARC_CORE1_H__

extern void InputSeriesFilter( int8_t *InputBuffer, int8_t *OutputBuffer, uint32_t BytesToProcess );

/*
 * ADC settings
 */
/* ADAU1979 SPORT config parameters */
#define LR_B_CLK_MASTER_1979    	(true)
#define BCLK_RISING_1979 	    	(true)
#ifdef TDM_MODE
#define LRCLK_HI_LO_1979 	    	(false)
#else
#define LRCLK_HI_LO_1979 	    	(true)
#endif

/* Sine wave parameters */
#define REFERENCE_FREQ 				(3000u)
#define SAMPLE_RATE   				(48000u)
#define SAMPLES_PER_PERIOD 			(SAMPLE_RATE) / (REFERENCE_FREQ)
#define SAMPLE_SIZE 				(4u)
#define NUM_CHANNELS				(4u)

/* Macro to set buffer size */
//#define AUDIO_BUFFER_SIZE 	        (SAMPLES_PER_PERIOD * NUM_CHANNELS * SAMPLE_SIZE * 4u)
#define AUDIO_BUFFER_SIZE 	        (SAMPLES_PER_PERIOD * NUM_CHANNELS * SAMPLE_SIZE)

/* IF (Debug info enabled) */
#if defined(ENABLE_DEBUG_INFO)
#define DBG_MSG                     printf
#else
#define DBG_MSG(...)
#endif

#endif /* __MULTICORETALKTHRUSHARCSHARC_CORE1_H__ */
